@@ -26,4 +26,8 @@ def get_schema_df(**kwargs: Any) -> pd.DataFrame:
         df_table.insert(1, "Table", table)
         return df_table
 
+    df_tables = wr.catalog.tables(**kwargs)
+    if df_tables.empty:
+        output_dtypes = {"Database": str, "Table": str, "Column Name": str, "Type": str, "Partition": bool, "Comment": str}
+        return pd.DataFrame({c: pd.Series(dtype=t) for c, t in output_dtypes.items()})
     return pd.concat([get_table_df(t.Database, t.Table) for t in wr.catalog.tables(**kwargs).itertuples()], ignore_index=True)
